@@ -257,7 +257,7 @@ class Component:
         if self.start_time == 0:
             rs = rs.set_start(self.start_time)
         if self.type !='element' and self.position['rotation'] != 0:
-            rs = rs.rotate(self.position['rotation'])
+            rs = rs.rotate(-1*self.position['rotation'])
         self.rs=rs
         return rs
     def close(self):
@@ -377,6 +377,7 @@ class VideoComp(Component):
         self.ext = json_data['ext']
         self.isMute = json_data['isMute']
         self.isLoop = json_data['isLoop']
+        self.isSmoothLoop = json_data['isSmoothLoop']
         self.isMask = json_data['isMask']
         self.maskColor = json_data['maskColor']
         self.md5 = json_data['md5']
@@ -393,7 +394,7 @@ class VideoComp(Component):
         if self.is_canva:
             self.kind = "canva"
     def get_clip(self):
-        if self.isLoop and self.ext != "gif" and not self.is_intro and not self.is_outro:
+        if self.isLoop and self.isSmoothLoop and self.ext != "gif" and not self.is_intro and not self.is_outro:
             obj = requests.get(self.mf_server+"resource/get-md5/"+self.kind+"/"+self.md5).json()
             if "id" in obj:
                 if "loop_link" in obj and obj['loop_link'] is not None and "gdrive" in obj['loop_link']:
